@@ -5,3 +5,5 @@
 # License: BSD (3-clause)
 
 from . import fnirs_motor_group
+from . import block_speech_noise
+from . import audio_or_visual_speech
