@@ -1,8 +1,7 @@
-"""Experimental design and analysis."""
-
 # Authors: Robert Luke <mail@robertluke.net>
 #
 # License: BSD (3-clause)
 
 from ._experimental_design import create_boxcar, \
-    make_first_level_design_matrix
+    make_first_level_design_matrix, longest_inter_annotation_interval, \
+    drift_high_pass
